@@ -2,19 +2,22 @@ package App::skryf::Model::User;
 
 use Mojo::Base 'App::skryf::Model::Base';
 use Method::Signatures;
+use Mango::BSON ':bson';
 
 method users {
     $self->mgo->db->collection('users');
 }
 
-method create ($username, $password) {
+method create ($username, $password, $attrs) {
     my $user = $self->users->find_one({username => $username});
+    my $bson = {
+      now => bson_time,
+      username => $username,
+      password => $password,
+      attrs => $attrs,
+    };
     if (!$user) {
-        $self->users->insert(
-            {   username => $username,
-                password => $password,
-            }
-        );
+        $self->users->insert($bson);
     }
     return 1;
 }
@@ -33,6 +36,10 @@ method check ($username, $password) {
     return undef;
 }
 
+method save ($user) {
+  $self->users->save($user);
+}
+
 1;
 __END__
 
@@ -66,6 +73,10 @@ Gets single user
 
 Removes user
 
+=head2 B<save>
+
+Saves user and attributes
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>. L<Mango>.
